@@ -44,7 +44,12 @@ $query = "SELECT * FROM {$this->MANUAL_TABLE}
 $dbresult =& $db->Execute($query);
 $row = $dbresult->FetchRow();
 
+# convert relative img URL to absolute
+
+$config = $gCms->getConfig();
+$view_content = preg_replace('#<img src="(?!http://)([^"]*)"#', "<img src=\"{$config['root_url']}/\$1\"", $row['man_content']);
+
 $smarty->assign('man_smarty', $row['man_smarty']);
-$smarty->assign('man_content', $row['man_content']);
+$smarty->assign('man_content', $view_content);
 echo $this->ProcessTemplate('admin_view_manual.tpl');
 ?>
